package com.notificationFramework.notification;

import android.annotation.TargetApi;
import android.app.NotificationChannel;
import android.content.Intent;
import android.support.v4.app.NotificationCompat;

import com.notificationFramework.sedentary.frontEnd.R;
import com.notificationFramework.sedentary.frontEnd.SaveFile;

/**
 * Created by Peter De Jonckheere on 09/03/2018.
 * <p>
 * The concrete implementation of Notification which sends a goal notification. It uses
 * a number of methods from SedentaryNotification with slight changes to the content of the
 * notification message and the vibration pattern to indicate a slightly different notification.
 * </p>
 */
public class GoalNotification extends SedentaryNotification {


    /**
     * Called when the service is started. Uses the Notification implementation of this method.
     * @param intent  the intent used to start the service
     * @param flags   additional information about the start request
     * @param startId the unique start id of this service
     * @return the return value of the Notification implementation of this method
     */
    @Override
    public int onStartCommand(Intent intent, int flags, int startId){
        return super.onStartCommand(intent, flags, startId);
    }

    /**
     * Implementation of the abstract method specified in Notification which adds individual
     * properties to the notification which is to be sent such as the content title and content
     * text.
     *
     * @param builder the NotificationCompat.Builder provided to be altered with unique properties
     * @return the altered version of 'builder'
     */
    @Override
    protected NotificationCompat.Builder setParameters(NotificationCompat.Builder builder) {
        builder = super.setParameters(builder);
        builder.setContentTitle(this.getClass().getSimpleName());
        builder.setContentText(preferences.getString(getString(R.string.goal_met), "Daily Goal Met"));
        SaveFile.recordNotification(1, 1, 0, 0, this);
        if (preferences.getBoolean(getString(R.string.vibration), false)) {
            builder.setVibrate(new long[]{0, 500, 0, 500});
        }
        return builder;
    }

    /**
     * Implementation of the abstract method specified in Notification which adds individual
     * properties to the NotificationChannel used if the API level is above 26.
     *
     * @param nc the NotificationChannel to be altered with individual properties
     * @return the altered version of NotificationChannel 'nc'
     */
    @TargetApi(26)
    protected NotificationChannel setChannelParameters(NotificationChannel nc) {
        nc = super.setChannelParameters(nc);
        nc.setDescription(this.getClass().getName());
        return nc;
    }
}
